

#appeler les libraries
library(dplyr)

#repertoire de travail
repertoire <- "C:/Users/User/OneDrive - alumni.manchester.ac.uk/documents/erpaa/reference_ad"
setwd(repertoire)

#lire le fichier csv
dataraw <- read.csv("input/activity_data_2000_2021.csv")

#foret gallerie (FG) et foret littoral degradee (FLD) seront transformee
#en foret humide degradee (FHD)

dataraw$alu_2006_subdivision <- recode(dataraw$alu_2006_subdivision, "FLD" = "FHD","FG" = "FHD")

###############################################
## calculer la deforestation entre 2006-2015
###############################################

t_student <- qt(0.95,nrow(dataraw)-1)
area_erpaa <- 6914785
defor_matrix <- dataraw %>%
  filter(alu_2006_category=="F"&alu_2015_category!="F") %>%
  group_by(alu_2006_subdivision) %>%
  summarise(freq_abs = n(),
            freq_rel = freq_abs/nrow(dataraw),
            variance = freq_rel*(1-freq_rel)/nrow(dataraw),
            std_error = sqrt(variance),
            uncertainty = t_student*std_error/freq_rel,
            area = freq_rel*area_erpaa,
            ci = uncertainty*area
            )
write.csv(defor_matrix,"output/rel_defor_matrix.csv")


####################################################
# degradation entre 2006-2015
####################################################

#definition of degradation
primary1 <- c("FHI","FLI","FSCI","FDSec","FX","M")
degraded1 <- c("FHD","FLD","FLSCD","FSecD","MD","ME","B","R","PLM","PLMS","PLMSf","FSR","FSS","AF")

primary2 <- c("FHD","FLD","FLSCD","FSecD","MD")
degraded2 <- c("ME","B","R","PLM","PLMS","PLMSf","FSR","FSS","AF")

degrad_matrix <- dataraw %>%
  filter(
    (alu_2006_subdivision %in% primary1) & (alu_2015_subdivision %in% degraded1)|
      (alu_2006_subdivision %in% primary2) & (alu_2015_subdivision %in% degraded2)
  )%>%
  group_by(alu_2006_subdivision) %>%
  summarise(freq_abs = n(),
            freq_rel = freq_abs/nrow(dataraw),
            variance = freq_rel*(1-freq_rel)/nrow(dataraw),
            std_error = sqrt(variance),
            uncertainty = t_student*std_error/freq_rel,
            area = freq_rel*area_erpaa,
            ci = uncertainty*area
  )
write.csv(degrad_matrix,"output/rel_degrad_matrix.csv")

##########################################################
# regeneration/gain entre 2006-2015
##########################################################
dataraw$alu_2015_subdivision <- recode(dataraw$alu_2015_subdivision, "FSR"="FSS")

regeneration_matrix <- dataraw %>%
  filter(alu_2006_category!="F"&alu_2015_category=="F") %>%
  group_by(alu_2015_subdivision) %>%
  summarise(freq_abs = n(),
            freq_rel = freq_abs/nrow(dataraw),
            variance = freq_rel*(1-freq_rel)/nrow(dataraw),
            std_error = sqrt(variance),
            uncertainty = t_student*std_error/freq_rel,
            area = freq_rel*area_erpaa,
            ci = uncertainty*area
  )
write.csv(regeneration_matrix,"output/rel_gain_matrix.csv")

#########################################################
# feux
#########################################################

fire_matrix <- dataraw %>%
  filter(human_impact_type_label=="Feux") %>%
  
  summarise(freq_abs = n(),
            freq_rel = freq_abs/nrow(dataraw),
            variance = freq_rel*(1-freq_rel)/nrow(dataraw),
            std_error = sqrt(variance),
            uncertainty = t_student*std_error/freq_rel,
            area = freq_rel*area_erpaa,
            ci = uncertainty*area
  )
write.csv(fire_matrix,"output/rel_fire_matrix.csv")


#################################################
#writing the ERPA activity data to file
#################################################

write.csv(dataraw,"output/activity_data_2000_2018.csv")

################################################
#identify secondary forest and plantation
################################################

fsec <- c("FSR","FSS","PLM","PLMS","PLMSf")


secondary_forest <- dataraw %>%
  filter(alu_2015_subdivision %in% fsec)
  
#write to file
write.csv(secondary_forest,"output/secondary_forest_2015.csv")

